wags-tails |version|
=========================

.. image:: https://img.shields.io/pypi/v/wags-tails.svg
   :alt: PyPI version
   :target: https://pypi.python.org/pypi/wags-tails

.. image:: https://img.shields.io/pypi/l/wags-tails.svg
   :alt: License
   :target: https://github.com/genomicmedlab/wags-tails/blob/main/LICENSE

.. image:: https://img.shields.io/pypi/pyversions/wags-tails?color=gr
   :alt: PyPI - supported Python versions

.. image:: https://github.com/genomicmedlab/wags-tails/actions/workflows/checks.yaml/badge.svg
   :alt: tests status
   :target: https://github.com/genomicmedlab/wags-tails/actions/workflows/checks.yaml

*Technology-Assisted Information Loading and Structure (TAILS) for Wagnerds.*

This tool provides data acquisition and access utilities for several projects developed by the `Wagner Lab <https://www.nationwidechildrens.org/specialties/institute-for-genomic-medicine/research-labs/wagner-lab>`_. It designates a storage location in user-space where external data files can be saved, and provides methods to download and update them when available.

It is currently used in:

* `Thera-Py <https://github.com/cancervariants/therapy-normalization>`_
* `Gene Normalizer <https://github.com/cancervariants/gene-normalization>`_
* `Disease Normalizer <https://github.com/cancervariants/disease-normalization>`_
* and more!

.. toctree::
   :hidden:
   :maxdepth: 2

    Installation<install>
    Usage<usage>
    API Reference<reference/index>
    Changelog<changelog>
    Contributing<contributing>
    License<license>
